root property
Directory holding the goldens, which the exporter writes as goldens/
beside the artifact.
Implementation
final String root;
Directory holding the goldens, which the exporter writes as goldens/
beside the artifact.
final String root;